@@ -1,4 +1,4 @@
-require 'gen/ConstGenerator'
+require_relative '../../gen/ConstGenerator'
 def gen_openflags_java(options)
   ConstGenerator.new 'platform.openflags', options do |cg|
     cg.include "fcntl.h"
@@ -26,6 +26,8 @@ def gen_openflags_java(options)
       O_SYMLINK
       O_BINARY
       O_NOCTTY
+      O_TMPFILE
+      O_CLOEXEC
     ]
     consts.each { |c| cg.const c }
   end
