@@ -1,4 +1,4 @@
-require 'gen/ConstGenerator'
+require_relative '../../gen/ConstGenerator'
 def gen_protocolfamily_java(options)
   ConstGenerator.new 'platform.protocol_family', options do |cg|
     cg.include "sys/socket.h"
@@ -44,4 +44,4 @@ def gen_protocolfamily_java(options)
       PF_MAX
     ].each {|c| cg.const c}
   end
-end
\ No newline at end of file
+end
