@@ -1,4 +1,4 @@
-require 'gen/ConstGenerator'
+require_relative '../../gen/ConstGenerator'
 def gen_shutdown_java(options)
   ConstGenerator.new 'platform.shutdown', options do |cg|
     cg.include "sys/socket.h"
@@ -9,4 +9,4 @@ def gen_shutdown_java(options)
       SHUT_RDWR
     ].each {|c| cg.const c}
   end
-end
\ No newline at end of file
+end
