@@ -1,4 +1,4 @@
-require 'gen/ConstGenerator'
+require_relative '../../gen/ConstGenerator'
 def gen_sock_java(options)
   ConstGenerator.new 'platform.sock', options do |cg|
     cg.include "sys/socket.h"
@@ -11,4 +11,4 @@ def gen_sock_java(options)
       SOCK_MAXADDRLEN
     ].each {|c| cg.const c}
   end
-end
\ No newline at end of file
+end
